
'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n != 1);
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(Ha \u00fcresen marad akkor a tulajdonos lesz az admin)",
    "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)": "(at least {passwordMinLength} characters and includes {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols)",
    "(at least {placeholder} characters)": "(at least {placeholder} characters)",
    "(current notification)": "(aktu\u00e1lis \u00e9rtes\u00edt\u00e9s)",
    "(current version)": "(aktu\u00e1lis verzi\u00f3)",
    "1 Year": "1 \u00e9v",
    "1 cell copied": "1 cell copied",
    "1 filter": "Egy sz\u0171r\u0151",
    "1 hidden property": "1 hidden property",
    "1 month ago": "1 h\u00f3napja",
    "1 preset hidden property": "1 preset hidden property",
    "1 record selected": "1 record selected",
    "1 row is copied.": "1 row is copied.",
    "1 sort": "Egy rendez\u00e9s",
    "1 week ago": "1 hete",
    "3 days ago": "3 napja",
    "30 Days": "30 nap",
    "7 Days": "7 nap",
    "A file is being uploaded. Are you sure you want to leave this page?": "A file is being uploaded. Are you sure you want to leave this page?",
    "A file named {upload_file_link} is uploaded to {uploaded_link}.": "A file named {upload_file_link} is uploaded to {uploaded_link}.",
    "A file named {upload_file_link} is uploaded.": "A file named {upload_file_link} is uploaded.",
    "A file with the same name already exists in this folder.": "A f\u00e1jl ezzel a n\u00e9vvel m\u00e1r l\u00e9tezik a k\u00f6nyvt\u00e1rban.",
    "A folder named {upload_folder_link} is uploaded to {uploaded_link}.": "A folder named {upload_folder_link} is uploaded to {uploaded_link}.",
    "A folder named {upload_folder_link} is uploaded.": "A folder named {upload_folder_link} is uploaded.",
    "API Token": "API Token",
    "API token is copied to the clipboard.": "API token is copied to the clipboard.",
    "About": "N\u00e9vjegy",
    "About Us": "N\u00e9vjegy",
    "Abuse Content": "Abuse Content",
    "Abuse Reports": "Abuse Reports",
    "Abuse Type": "Abuse Type",
    "Abuse report added": "Abuse report added",
    "Accept": "Elfogad",
    "Accepted": "Elfogadva",
    "Accepted at": "Elfogad\u00e1s ideje",
    "Accepter": "Elfogad\u00f3",
    "Access Log": "Hozz\u00e1f\u00e9r\u00e9si napl\u00f3",
    "Accurate to minute": "Accurate to minute",
    "Action": "M\u0171velet",
    "Actions": "Tennival\u00f3k",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Felhaszn\u00e1l\u00f3 automatikus aktiv\u00e1l\u00e1sa regisztr\u00e1ci\u00f3 ut\u00e1n. Amennyiben nincs bepip\u00e1lva, a felhaszn\u00e1l\u00f3t aktiv\u00e1lni kell egy adminisztr\u00e1tornak, vagy aktiv\u00e1l\u00f3 E-mail seg\u00edts\u00e9g\u00e9vel.",
    "Activated": "Aktiv\u00e1lva",
    "Activated Users": "Aktiv\u00e1lt felhaszn\u00e1l\u00f3k",
    "Active": "Akt\u00edv",
    "Active Users": "Bejelentkezett felhaszn\u00e1l\u00f3k",
    "Activities": "Tev\u00e9kenys\u00e9gek",
    "Add": "Hozz\u00e1ad",
    "Add Admin": "Add Admin",
    "Add Library": "K\u00f6tet hozz\u00e1ad\u00e1sa",
    "Add Member": "Tag hozz\u00e1ad\u00e1sa",
    "Add Organization": "Add Organization",
    "Add Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek hozz\u00e1ad\u00e1sa",
    "Add User": "Felhaszn\u00e1l\u00f3 hozz\u00e1ad\u00e1sa",
    "Add Wiki": "Wiki hozz\u00e1ad\u00e1sa",
    "Add admin": "Adminisztr\u00e1tor hozz\u00e1ad\u00e1sa",
    "Add auto expiration": "Automatikus lej\u00e1rat be\u00e1ll\u00edt\u00e1sa",
    "Add cover": "Add cover",
    "Add custom permission": "Egyedi jogosults\u00e1g hozz\u00e1ad\u00e1sa",
    "Add filter": "Sz\u0171r\u0151 hozz\u00e1ad\u00e1sa",
    "Add group": "Add group",
    "Add group member": "Add group member",
    "Add icon": "Add icon",
    "Add institution": "Int\u00e9zm\u00e9ny hozz\u00e1ad\u00e1sa",
    "Add members": "Tagok hozz\u00e1ad\u00e1sa",
    "Add new notification": "\u00daj \u00e9rtes\u00edt\u00e9s hozz\u00e1ad\u00e1sa",
    "Add option": "Add option",
    "Add password protection": "Jelsz\u00f3 v\u00e9delem hozz\u00e1ad\u00e1sa",
    "Add permission": "Add permission",
    "Add sort": "Rendez\u00e9s hozz\u00e1ad\u00e1sa",
    "Add user": "Felhaszn\u00e1l\u00f3 hozz\u00e1ad\u00e1sa",
    "Add view": "Add view",
    "Added": "Hozz\u00e1adva",
    "Added user {user}": "Felhaszn\u00e1l\u00f3 hozz\u00e1adva: {user}",
    "Admin": "Adminisztr\u00e1tor",
    "Admin Login Logs": "Admin bejelentkez\u00e9si napl\u00f3",
    "Admin Logs": "Admin napl\u00f3",
    "Admin Operation Logs": "Admin m\u0171veletek napl\u00f3",
    "Admin access": "Admin hozz\u00e1f\u00e9r\u00e9s",
    "Admins": "Adminisztr\u00e1torok",
    "Advanced": "Advanced",
    "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.": "After enable extended properties for files, you can add different properties to files, like collaborators, file expiring time, file description. You can also create different views for files based extended properties.",
    "All": "Mind",
    "All Groups": "Minden csoport",
    "All Notifications": "\u00d6sszes \u00e9rtes\u00edt\u00e9s",
    "All Public Links": "\u00d6sszes nyilv\u00e1nos link",
    "All comments": "\u00d6sszes megjegyz\u00e9s",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Regisztr\u00e1ci\u00f3k enged\u00e9lyez\u00e9se. Vegye ki a pip\u00e1t, hogy megakad\u00e1lyozza \u00faj felhaszn\u00e1l\u00f3k regisztr\u00e1l\u00e1s\u00e1t.",
    "An integer that is greater than 0 or equal to -2.": "0-n\u00e1l nagyobb, vagy -2-vel egyenl\u0151 eg\u00e9sz sz\u00e1m.",
    "An integer that is greater than or equal to 0.": "0-n\u00e1l nagyobb vagy egyenl\u0151 eg\u00e9sz.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "A bels\u0151 link seg\u00edts\u00e9g\u00e9vel azon a felhaszn\u00e1l\u00f3k \u00e9rhetik el a f\u00e1jlt, vagy mapp\u00e1t, akik rendelkeznek olvas\u00e1si joggal az adott f\u00e1jlon, vagy mapp\u00e1n.",
    "And": " \u00c9s",
    "Anonymous User": "Anonymous felhaszn\u00e1l\u00f3",
    "Another property has this property type": "Another property has this property type",
    "Another user is editing this file!": "Another user is editing this file!",
    "Anyone with the link": "Anyone with the link",
    "Are you sure to change group {placeholder} to department ?": "Are you sure to change group {placeholder} to department ?",
    "Are you sure to delete": "Biztosan t\u00f6rli?",
    "Are you sure to delete ": "Are you sure to delete ",
    "Are you sure to delete this comment?": "Biztosan t\u00f6r\u00f6lni szeretn\u00e9 ezt a kommentet?",
    "Are you sure to delete this reply?": "Biztosan t\u00f6r\u00f6lni szeretn\u00e9 ezt a v\u00e1laszot?",
    "Are you sure to revoke access of user {placeholder} ?": "Are you sure to revoke access of user {placeholder} ?",
    "Are you sure you want to clear trash?": "Biztos, hogy \u00fcr\u00edti a kuk\u00e1t?",
    "Are you sure you want to delete": "Are you sure you want to delete",
    "Are you sure you want to delete WebDAV password?": "Are you sure you want to delete WebDAV password?",
    "Are you sure you want to delete the notification ?": "Are you sure you want to delete the notification ?",
    "Are you sure you want to delete the selected share link(s) ?": "Are you sure you want to delete the selected share link(s) ?",
    "Are you sure you want to delete the selected user(s) ?": "Biztoson t\u00f6r\u00f6lni k\u00edv\u00e1nja a kijelelt felhaszn\u00e1l\u00f3(ka)t?",
    "Are you sure you want to delete the share link?": "Biztosan t\u00f6rli a megoszt\u00e1si linket?",
    "Are you sure you want to delete this page?": "Biztos, hogy t\u00f6rli ezt az oldalt?",
    "Are you sure you want to delete {placeholder} ?": "Are you sure you want to delete {placeholder} ?",
    "Are you sure you want to delete {placeholder} completely?": "Are you sure you want to delete {placeholder} completely?",
    "Are you sure you want to disconnect?": "Are you sure you want to disconnect?",
    "Are you sure you want to remove {placeholder} ?": "Are you sure you want to remove {placeholder} ?",
    "Are you sure you want to reset the password of {placeholder} ?": "Are you sure you want to reset the password of {placeholder} ?",
    "Are you sure you want to restore this library?": "Biztosan vissza\u00e1ll\u00edtja a k\u00f6tetet?",
    "Are you sure you want to restore {placeholder}?": "Are you sure you want to restore {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "Are you sure you want to revoke the admin permission of {placeholder} ?",
    "Are you sure you want to set {placeholder} as Admin?": "Are you sure you want to set {placeholder} as Admin?",
    "Are you sure you want to set {user_placeholder} inactive?": "Are you sure you want to set {user_placeholder} inactive?",
    "Are you sure you want to unlink this device?": "Biztosan sz\u00e9tkapcsolja az eszk\u00f6zt?",
    "At server": "At server",
    "Audio": "Zene",
    "Auth Token created": "Auth Token created",
    "Auth Token deleted": "Auth Token deleted",
    "Auto deletion": "Auto deletion",
    "Automatically delete files that are not modified within certain days:": "Automatically delete files that are not modified within certain days:",
    "Avatar": "Avatar:",
    "Avatar updated": "Avatar updated",
    "Avatar:": "Avatar:",
    "Back": "Vissza",
    "Basic": "Basic",
    "Bell Icon": "Bell Icon",
    "Besides Write permission, user can also share the library.": "Besides Write permission, user can also share the library.",
    "Branding": "Branding",
    "Broken (please contact your administrator to fix this library)": "S\u00e9r\u00fclt (a k\u00f6tet jav\u00edt\u00e1sa \u00e9rdek\u00e9ben k\u00e9rem \u00e9rtes\u00edtse az adminisztr\u00e1tort)",
    "By day": "By day",
    "By month": "By month",
    "By name ascending": "By name ascending",
    "By name descending": "By name descending",
    "By quarter": "By quarter",
    "By size ascending": "By size ascending",
    "By size descending": "By size descending",
    "By time ascending": "By time ascending",
    "By time descending": "By time descending",
    "By week": "By week",
    "By year": "By year",
    "Can not copy folder %(src)s to its subfolder %(des)s": "Can not copy folder %(src)s to its subfolder %(des)s",
    "Can not move folder %(src)s to its subfolder %(des)s": "Can not move folder %(src)s to its subfolder %(des)s",
    "Cancel": "M\u00e9gsem",
    "Cancel All": "Mindet kivesz",
    "Cannot move parent page to child page": "Cannot move parent page to child page",
    "Capture information": "Capture information",
    "Capture time": "Capture time",
    "Card": "K\u00e1rtya",
    "Certificate": "Certificate",
    "Change": "V\u00e1ltoztat\u00e1s",
    "Change Password": "Jelsz\u00f3 v\u00e1ltoztat\u00e1s",
    "Change Password of Library {placeholder}": "Jelsz\u00f3 megv\u00e1ltoztat\u00e1sa a k\u00f6tethez:  {placeholder}",
    "Change cover": "Change cover",
    "Change group to department": "Change group to department",
    "Change to department": "Change to department",
    "Changes": "V\u00e1ltoz\u00e1sok",
    "Checkbox": "Checkbox",
    "Choose date": "Choose date",
    "Clean": "T\u00f6r\u00f6l",
    "Clean succeeded.": "Clean succeeded.",
    "Cleaned trash": "Cleaned trash",
    "Clear": "Tiszt\u00edt",
    "Clear Trash": "Kuka \u00fcr\u00edt\u00e9se",
    "Clear files in trash and history\uff1a": "F\u00e1jlok t\u00f6rl\u00e9se a kuk\u00e1b\u00f3l \u00e9s az el\u0151zm\u00e9nyekb\u0151l :",
    "Clear selected": "Clear selected",
    "Clients": "Kliensek",
    "Close": "Bez\u00e1r\u00e1s",
    "Close (Esc)": "Bez\u00e1r (Esc)",
    "Code": "K\u00f3d",
    "Collaborator": "Collaborator",
    "Collaborators": "Kollabor\u00e1torok",
    "Collapse all": "Collapse all",
    "Color space": "Color space",
    "Comment": "Megjegyz\u00e9s",
    "Comment details": "Koment r\u00e9szletei",
    "Comments": "Megjegyz\u00e9sek",
    "Community Edition": "K\u00f6z\u00f6ss\u00e9gi verzi\u00f3",
    "Compressed": "Compressed",
    "Configure Seafile": "Configure Seafile",
    "Configure your Identity Provider": "Configure your Identity Provider",
    "Confirm": "Meger\u0151s\u00edt\u00e9s",
    "Confirm Password": "Jelsz\u00f3 meger\u0151s\u00edt\u00e9se",
    "Confirm password": "Confirm password",
    "Connect": "Connect",
    "Contact Email": "Kapcsolat email",
    "Contact Email:": "Kapcsolat email:",
    "Contact Information": "Contact Information",
    "Contact information is required.": "Contact information is required.",
    "Content Scan Records": "Content Scan Records",
    "Convert & Export": "Convert & Export",
    "Convert Wiki": "Convert Wiki",
    "Convert to Markdown": "Convert to Markdown",
    "Convert to docx": "Convert to docx",
    "Convert to sdoc": "Convert to sdoc",
    "Convert with ONLYOFFICE": "Convert with ONLYOFFICE",
    "Converting, please wait...": "Converting, please wait...",
    "Copied": "\u00c1tm\u00e1solva",
    "Copied link to clipboard": "Copied link to clipboard",
    "Copy": "M\u00e1sol\u00e1s",
    "Copy failed": "Copy failed",
    "Copy link": "Copy link",
    "Copy selected": "Copy selected",
    "Copy selected item(s) to:": "Kiv\u00e1lasztott elem(ek) m\u00e1sol\u00e1sa ide:",
    "Copy the IdP's certificate and paste it here. The certificate format is as follows:": "Copy the IdP's certificate and paste it here. The certificate format is as follows:",
    "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.": "Copy the domain DNS TXT and add it to your domain's DNS records, then click the button to verify domain ownership. You must verify the ownership of domain before Single Sign-On.",
    "Copy {num} items": "Copy {num} items",
    "Copy {placeholder} to": "Copy {placeholder} to",
    "Copyright Infringement": "Copyright Infringement",
    "Count": "Sz\u00e1ml\u00e1l\u00f3",
    "Cover": "Cover",
    "Create": "L\u00e9trehoz\u00e1s",
    "Create At": "L\u00e9trehoz\u00e1s helye:",
    "Create Group": "Csoport l\u00e9trehoz\u00e1sa",
    "Create Library": "K\u00f6tet l\u00e9trehoz\u00e1sa",
    "Create Report": "Jelent\u00e9s k\u00e9sz\u00edt\u00e9se",
    "Create a DNS TXT record to confirm the ownership of your Email Domain.": "Create a DNS TXT record to confirm the ownership of your Email Domain.",
    "Create a new tag": "\u00daj c\u00edmke l\u00e9trehoz\u00e1sa",
    "Created": "L\u00e9trehozva",
    "Created At": "L\u00e9trehozva",
    "Created Files": "L\u00e9trehozott f\u00e1jlok",
    "Created draft": "L\u00e9trehozott piszkozat",
    "Created file": "L\u00e9trehozott f\u00e1jl",
    "Created folder": "L\u00e9trehozott mappa",
    "Created group {group_name}": "Csoport l\u00e9trehozva: {group_name}",
    "Created library": "K\u00f6tet l\u00e9trehozva",
    "Created library {library_name} with {owner} as its owner": "{library_name} l\u00e9trehozva. Tulajdonos: {owner}",
    "Created time": "L\u00e9trehoz\u00e1s ideje",
    "Created {n} files": "Created {n} files",
    "Creator": "L\u00e9trehoz\u00f3",
    "Current Connected Devices": "Csatlakozott eszk\u00f6z\u00f6k",
    "Current Library": "Aktu\u00e1lis k\u00f6tet",
    "Current Path: ": "Aktu\u00e1lis \u00fatvonal: ",
    "Current Version": "Aktu\u00e1lis verzi\u00f3",
    "Current page": "Current page",
    "Current password": "Current password",
    "Current password cannot be blank": "A jelenlegi jelsz\u00f3 nem lehet \u00fcres",
    "Current path: ": "Aktu\u00e1lis \u00fatvonal: ",
    "Custom CSS": "Egy\u00e9ni CSS",
    "Custom properties": "Custom properties",
    "Custom sharing permissions": "Custom sharing permissions",
    "Customize URL": "Customize URL",
    "DNS TXT Value": "DNS TXT Value",
    "Date": "D\u00e1tum",
    "Date Invalid.": "Date Invalid.",
    "Day": "Day",
    "Default": "Alap\u00e9rtelmezett",
    "Delete": "T\u00f6rl\u00e9s",
    "Delete Account": "Fi\u00f3k t\u00f6rl\u00e9se",
    "Delete Department": "Oszt\u00e1ly t\u00f6rl\u00e9se",
    "Delete Expired Invitations": "Lej\u00e1rt megh\u00edvok t\u00f6rl\u00e9se",
    "Delete File": "F\u00e1jl t\u00f6rl\u00e9se",
    "Delete Folder": "Mappa t\u00f6rl\u00e9se",
    "Delete Group": "Csoport t\u00f6rl\u00e9se",
    "Delete Institution": "Int\u00e9zm\u00e9ny t\u00f6rl\u00e9se",
    "Delete Library": "K\u00f6tet t\u00f6rl\u00e9se",
    "Delete Member": "Tag elt\u00e1vol\u00edt\u00e1sa",
    "Delete Notification": "\u00c9rtes\u00edt\u00e9s t\u00f6rl\u00e9se",
    "Delete Organization": "Szervezet t\u00f6rl\u00e9se",
    "Delete Password": "Delete Password",
    "Delete T&C": "Delete T&C",
    "Delete User": "Felhaszn\u00e1l\u00f3 t\u00f6rl\u00e9se",
    "Delete Users": "Delete Users",
    "Delete WebDAV Password": "Delete WebDAV Password",
    "Delete Wiki": "Wiki t\u00f6rl\u00e9se",
    "Delete file": "Delete file",
    "Delete files from this device the next time it comes online.": "T\u00f6r\u00f6lje a f\u00e1jlokat az eszk\u00f6zr\u0151l, amikor legk\u00f6zelebb online lesz.",
    "Delete folder": "Delete folder",
    "Delete group": "Delete group",
    "Delete page": "Delete page",
    "Delete property": "Delete property",
    "Delete selected": "Delete selected",
    "Delete share links": "Delete share links",
    "Deleted": "T\u00f6r\u00f6lve",
    "Deleted Libraries": "T\u00f6r\u00f6lt k\u00f6tetek",
    "Deleted Time": "T\u00f6rl\u00e9s ideje",
    "Deleted directories": "T\u00f6r\u00f6lt k\u00f6nyvt\u00e1rak",
    "Deleted draft": "T\u00f6r\u00f6lt piszkozat",
    "Deleted file": "T\u00f6r\u00f6lt f\u00e1jl",
    "Deleted files": "T\u00f6r\u00f6lt f\u00e1jlok",
    "Deleted folder": "T\u00f6r\u00f6lt mappa",
    "Deleted group {group_name}": "Csoport t\u00f6r\u00f6lve: {group_name}",
    "Deleted library": "T\u00f6r\u00f6lt k\u00f6tet",
    "Deleted library {library_name}": "{library_name} k\u00f6tet t\u00f6r\u00f6lve",
    "Deleted option": "Deleted option",
    "Deleted user %s": "Deleted user %s",
    "Deleted user {user}": "Felhaszn\u00e1l\u00f3 t\u00f6r\u00f6lve: {user}",
    "Department renamed": "Department renamed",
    "Departments": "Oszt\u00e1lyok",
    "Description": "Le\u00edr\u00e1s",
    "Description is required": "Le\u00edr\u00e1s k\u00f6telez\u0151",
    "Desktop": "Desktop",
    "Detail": "R\u00e9szletek",
    "Details": "R\u00e9szletek",
    "Device": "Eszk\u00f6z",
    "Device Name": "Eszk\u00f6z neve",
    "Device make": "Device make",
    "Device model": "Device model",
    "Devices": "Eszk\u00f6z\u00f6k",
    "Dimensions": "Dimensions",
    "Direct download link": "Direct download link",
    "Direct download link is copied to the clipboard.": "K\u00f6zvetlen let\u00f6lt\u00e9si link v\u00e1g\u00f3lapra m\u00e1solva",
    "Disable Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s kikapcsol\u00e1sa",
    "Disconnect": "Disconnect",
    "Discussion": "Megbesz\u00e9l\u00e9s",
    "Display files": "Display files",
    "Do not automatically delete files": "Do not automatically delete files",
    "Do you really want to turn off extended properties? Existing properties will all be deleted.": "Do you really want to turn off extended properties? Existing properties will all be deleted.",
    "Document": "Document",
    "Document conversion failed.": "Document conversion failed.",
    "Document keywords": "Document keywords",
    "Domain verified": "Domain verified",
    "Don't ignore": "Don't ignore",
    "Don't keep history": "Csak az utols\u00f3 v\u00e1ltozat megtart\u00e1sa",
    "Don't replace": "Ne cser\u00e9lje",
    "Don't send emails": "Don't send emails",
    "Done": "Done",
    "Down": "Cs\u00f6kken\u0151 sorrend",
    "Download": "Let\u00f6lt\u00e9s",
    "Download an example file": "Mintaf\u00e1jl let\u00f6lt\u00e9se",
    "Download and upload": "Let\u00f6lt\u00e9s \u00e9s felt\u00f6lt\u00e9s",
    "Duplicate": "Duplicate",
    "Duplicate page": "Duplicate page",
    "Edit": "Szerkeszt\u00e9s",
    "Edit format settings": "Edit format settings",
    "Edit labels": "C\u00edmk\u00e9k szerkeszt\u00e9se",
    "Edit metadata properties": "Edit metadata properties",
    "Edit multiple select": "Edit multiple select",
    "Edit on cloud and download": "Szerkeszt\u00e9s a felh\u0151ben \u00e9s let\u00f6lt\u00e9s",
    "Edit on cloud only": "Edit on cloud only",
    "Edit permission": "Edit permission",
    "Edit single select": "Edit single select",
    "Edit succeeded": "Szerkeszt\u00e9s sikeres.",
    "Edit succeeded.": "Edit succeeded.",
    "Email": "E-mail",
    "Email Domain": "Email Domain",
    "Email Notification": "Email Notification",
    "Email is invalid.": "Email is invalid.",
    "Email notification updated": "Email notification updated",
    "Emails": "Emails",
    "Emails, separated by ','": "E-mail c\u00edmek \u201d,\u201d-vel elv\u00e1lasztva ",
    "Emojis": "Emojis",
    "Empty": "\u00dcres",
    "Enable Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s bekapcsol\u00e1sa",
    "Enable extended properties": "Enable extended properties",
    "Enable face recognition to identify people in your photos.": "Enable face recognition to identify people in your photos.",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Enged\u00e9lyezi az Adminisztr\u00e1toroknak Felhaszn\u00e1l\u00e1si felt\u00e9telek l\u00e9trehoz\u00e1s\u00e1t, melyeket minden felhaszn\u00e1l\u00f3nak el kell fogadnia.",
    "Enable two factor authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s enged\u00e9lyez\u00e9se",
    "Enable users to share libraries to any groups in the system.": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3knak, k\u00f6tetek megoszt\u00e1s\u00e1t b\u00e1rmely csoporttal a rendszerben.",
    "Encrypt": "Titkos\u00edt\u00e1s",
    "Encrypted library": "Titkos\u00edtott k\u00f6tet",
    "End date": "End date",
    "Enter characters to start searching": "Enter characters to start searching",
    "Error": "Hiba",
    "Errors": "Hib\u00e1k",
    "European": "European",
    "Exact date": "Exact date",
    "Exit Institution Admin": "Exit Institution Admin",
    "Exit Organization Admin": "Exit Organization Admin",
    "Exit System Admin": "Admin kil\u00e9p\u00e9s",
    "Expand all": "Expand all",
    "Expiration": "Lej\u00e1rat",
    "Expiration days": "Lej\u00e1rati napok sz\u00e1ma",
    "Expiration time": "Lej\u00e1rat id\u0151pontja",
    "Expired": "Lej\u00e1rt",
    "Expired at": "Lej\u00e1rt",
    "Export": "Export",
    "Export Excel": "Export\u00e1l\u00e1s Excelbe",
    "Export as docx": "Export as docx",
    "Export as zip": "Export as zip",
    "Export tags": "Export tags",
    "Exporting": "Exporting",
    "Exporting...": "Exporting...",
    "Exposure time": "Exposure time",
    "Extended properties": "Extended properties",
    "Extension Prompts": "Extension Prompts",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Sz\u00f6veg f\u00e1jl kiterjeszt\u00e9sek, melyek online megtek\u00edthet\u0151ek. Minden v\u00e9gz\u0151d\u00e9st ','-vel kell elv\u00e1lasztani.",
    "Extract file detail": "Extract file detail",
    "Extract file details": "Extract file details",
    "F number": "F number",
    "Face recognition": "Face recognition",
    "Failed": "Sikertelen",
    "Failed imported options": "Failed imported options",
    "Failed to convert {name}.": "Failed to convert {name}.",
    "Failed to copy %(name)s": "%(name)s m\u00e1sol\u00e1sa sikertelen",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Failed to copy %(name)s and %(amount)s other item(s).",
    "Failed to copy %(name)s.": "Failed to copy %(name)s.",
    "Failed to copy files to another library.": "Failed to copy files to another library.",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Failed to delete %(virus_file) from library %(library): %(error_msg)",
    "Failed to delete property": "Failed to delete property",
    "Failed to delete records": "Failed to delete records",
    "Failed to delete {name}": "Failed to delete {name}",
    "Failed to delete {name} and {n} other items.": "Failed to delete {name} and {n} other items.",
    "Failed to delete {name}.": "Failed to delete {name}.",
    "Failed to download. The total size of the files exceeded the limit.": "Failed to download. The total size of the files exceeded the limit.",
    "Failed to duplicate page": "Failed to duplicate page",
    "Failed to export. Please check whether the size of table attachments exceeds the limit.": "Failed to export. Please check whether the size of table attachments exceeds the limit.",
    "Failed to extract file details": "Failed to extract file details",
    "Failed to generate description": "Failed to generate description",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Failed to ignore %(virus_file) from library %(library): %(error_msg)",
    "Failed to insert property": "Failed to insert property",
    "Failed to modify filter": "Failed to modify filter",
    "Failed to modify group": "Failed to modify group",
    "Failed to modify hidden properties": "Failed to modify hidden properties",
    "Failed to modify people name": "Failed to modify people name",
    "Failed to modify property data": "Failed to modify property data",
    "Failed to modify property order": "Failed to modify property order",
    "Failed to modify records": "Failed to modify records",
    "Failed to modify sort": "Failed to modify sort",
    "Failed to move %(name)s and %(amount)s other item(s).": "Failed to move %(name)s and %(amount)s other item(s).",
    "Failed to move %(name)s.": "Failed to move %(name)s.",
    "Failed to move files to another library.": "Failed to move files to another library.",
    "Failed to move {name}.": "Failed to move {name}.",
    "Failed to rename property": "Failed to rename property",
    "Failed to restore records": "Failed to restore records",
    "Failed to restore {name}": "Failed to restore {name}",
    "Failed to restore {name} and {n} other items": "Failed to restore {name} and {n} other items",
    "Failed to save": "Failed to save",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Failed to send to {email_placeholder}: {errorMsg_placeholder}",
    "Failed to unshare {name}": "Failed to unshare {name}",
    "Failed to upload {file_name}.": "Failed to upload {file_name}.",
    "Failed. Please check the network.": "Sikertelen. Ellen\u0151rizze a h\u00e1l\u00f3zatot.",
    "Favorites": "Kedvencek",
    "File": "F\u00e1jl",
    "File Access": "F\u00e1jl hozz\u00e1f\u00e9r\u00e9s",
    "File Operations": "F\u00e1jlm\u0171veletek",
    "File Update": "F\u00e1jl friss\u00edt\u00e9s",
    "File Upload": "F\u00e1jl felt\u00f6lt\u00e9s",
    "File Uploading...": "F\u00e1jl felt\u00f6lt\u00e9s ...",
    "File already exists.": "File already exists.",
    "File collaborators": "File collaborators",
    "File details": "File details",
    "File download is disabled: the share link traffic of owner is used up.": "F\u00e1jl let\u00f6lt\u00e9s letiltva: a megoszt\u00e1si link tulajdonosa el\u00e9rte a forgalmi korl\u00e1tot.",
    "File expire time": "File expire time",
    "File extension white list": "File extension white list",
    "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.": "File extension white list for file upload via web UI and API. For example, \"md;txt;docx\". Empty means no limit.",
    "File extensions can only be {placeholder}.": "File extensions can only be {placeholder}.",
    "File is locked by others.": "File is locked by others.",
    "File name": "File name",
    "File owner": "File owner",
    "File reviewer": "File reviewer",
    "File size is too large.": "File size is too large.",
    "File status": "File status",
    "File too large": "File too large",
    "File type": "File type",
    "Files": "F\u00e1jlok",
    "Files and folders": "Files and folders",
    "Filter": "Sz\u0171r\u0151",
    "Filters": "Filters",
    "Find a tag": "Find a tag",
    "Find modifiers": "Find modifiers",
    "Focal length": "Focal length",
    "Folder": "K\u00f6nyvt\u00e1r",
    "Folder Permission": "K\u00f6nyvt\u00e1r jogosults\u00e1g",
    "Folder does not exist.": "A mappa nem l\u00e9tezik.",
    "Folders": "K\u00f6nyvt\u00e1rak",
    "Force Two-Factor Authentication": "K\u00f6telez\u0151 k\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s",
    "Force user to change password when account is newly added or reset by admin": "K\u00e9nyszer\u00edti a felhaszn\u00e1l\u00f3t jelszav\u00e1nak megv\u00e1ltoztat\u00e1s\u00e1ra, \u00faj felhaszn\u00e1l\u00f3i fi\u00f3k l\u00e9trehoz\u00e1sakor, vagy ha egy Adminisztr\u00e1tor alaphelyzetbe \u00e1ll\u00edtja azt.",
    "Force user to use a strong password when sign up or change password.": "Megk\u00f6veteli a felhaszn\u00e1l\u00f3t\u00f3l er\u0151s jelsz\u00f3 haszn\u00e1lat\u00e1t regisztr\u00e1ci\u00f3 vagy jelsz\u00f3v\u00e1lt\u00e1s alkalm\u00e1val.",
    "Format": "Format",
    "Freeze Document": "Freeze Document",
    "Freeze user account when failed login attempts exceed limit.": "Felhaszn\u00e1l\u00f3i fi\u00f3k felf\u00fcggeszt\u00e9se, ha a sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek sz\u00e1ma el\u00e9rte a limitet.",
    "Frozen by {name}": "Frozen by {name}",
    "Full screen": "Teljes k\u00e9perny\u0151",
    "Gallery": "Gallery",
    "General information": "General information",
    "Generate": "Gener\u00e1l",
    "Generate Link": "Generate Link",
    "Generate description": "Generate description",
    "Generate links in batch": "Generate links in batch",
    "Generate share link": "Generate share link",
    "Germany Russia etc": "Germany Russia etc",
    "Global Address Book": "Glob\u00e1lis n\u00e9vjegyz\u00e9k",
    "Greater than or equal to {minDays_placeholder} days": "Legal\u00e1bb {minDays_placeholder} nap",
    "Grid view": "Grid view",
    "Group": "Csoport",
    "Group Permission": "Csoport jogosults\u00e1g",
    "Group Shares": "Group Shares",
    "Group by": "Group by",
    "Group members": "Group members",
    "Grouped by 1 property": "Grouped by 1 property",
    "Groups": "Csoportok",
    "Guest": "Vend\u00e9g",
    "Handled": "Kezelve",
    "Help": "Seg\u00edts\u00e9g",
    "Hide": "Elrejt",
    "Hide all": "Mindet elrejt",
    "Hide properties": "Hide properties",
    "History": "Napl\u00f3",
    "History Setting": "Napl\u00f3be\u00e1ll\u00edt\u00e1sok",
    "History Versions": "Kor\u00e1bbi verzi\u00f3k",
    "IP": "IP",
    "ISO": "ISO",
    "If notifications have not been read within one hour, they will be sent to your mailbox.": "If notifications have not been read within one hour, they will be sent to your mailbox.",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Ha bekapcsolva, az asztali kliensalkalmaz\u00e1sok nem tudnak az alap\u00e9rtelmezett Seafile mapp\u00e1n k\u00edv\u00fcli mapp\u00e1t szinkroniz\u00e1lni.",
    "If you don't have any device with you, you can access your account using backup codes.": "Amennyiben nincs \u00f6nn\u00e9l az azonos\u00edt\u00f3 eszk\u00f6z, haszn\u00e1lhatja a tartal\u00e9k k\u00f3dokat fi\u00f3kja el\u00e9r\u00e9s\u00e9hez.",
    "Ignore": "Ignore",
    "Ignored": "Ignored",
    "Import Users": "Import Users",
    "Import members": "Import members",
    "Import members from a .xlsx file": "Import members from a .xlsx file",
    "Import options": "Import options",
    "Import sdoc": "Import sdoc",
    "Import tags": "Import tags",
    "Import users": "Felhaszn\u00e1l\u00f3k import\u00e1l\u00e1sa",
    "Import users from a .xlsx file": "Felhaszn\u00e1l\u00f3k import\u00e1l\u00e1sa .xlsx f\u00e1jlb\u00f3l",
    "In progress": "In progress",
    "In review": "In review",
    "Inactive": "Nem akt\u00edv",
    "Info": "Inf\u00f3.",
    "Institution Admin": "Institution Admin",
    "Institutions": "Int\u00e9zm\u00e9nyek",
    "Internal Link": "Bels\u0151 link",
    "Internal Server Error": "Bels\u0151 kiszolg\u00e1l\u00f3hiba",
    "Internal link has been copied to clipboard": "Bels\u0151 link a v\u00e1g\u00f3lapra m\u00e1solva",
    "Invalid destination path": "\u00c9rv\u00e9nytelen c\u00e9l \u00fatvonal",
    "Invalid filename.": "Invalid filename.",
    "Invalid filter": "\u00c9rv\u00e9nytelen sz\u0171r\u0151",
    "Invalid month, should be yyyymm.": "\u00c9rv\u00e9nytelen h\u00f3nap, helyes form\u00e1tum: \u00e9\u00e9\u00e9\u00e9-hh",
    "Invalid regular expression": "Invalid regular expression",
    "Invisible": "Invisible",
    "Invitations": "Megh\u00edv\u00e1sok",
    "Invite Guest": "Invite Guest",
    "Invite Time": "Megh\u00edv\u00e1s ideje",
    "Invite users": "Invite users",
    "Invited at": "Megh\u00edv\u00e1s ideje",
    "Inviter": "Megh\u00edv\u00f3",
    "Is expired": "Is expired",
    "It is required.": "Sz\u00fcks\u00e9ges.",
    "It may take some time, please wait.": "It may take some time, please wait.",
    "Keep full history": "\u00d6sszes v\u00e1ltozat megtart\u00e1sa",
    "Keep sharing": "Keep sharing",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(bet\u00f6ltve)",
    "Label": "C\u00edmke",
    "Label Current State": "Label Current State",
    "Labels": "C\u00edmk\u00e9k",
    "Language": "Nyelv",
    "Language Setting": "Nyelvi be\u00e1ll\u00edt\u00e1sok",
    "Last Access": "Utols\u00f3 el\u00e9r\u00e9s",
    "Last Login": "Utols\u00f3 bel\u00e9p\u00e9s",
    "Last Update": "Utols\u00f3 friss\u00edt\u00e9s ",
    "Last modification": "Utols\u00f3 m\u00f3dos\u00edt\u00e1s",
    "Last modified by": "Utolj\u00e1ra m\u00f3dos\u00edt\u00f3",
    "Last modified time": "Last modified time",
    "Last modifier": "Last modifier",
    "Leave": "Leave",
    "Leave Group": "Leave Group",
    "Leave Share": "Megoszt\u00e1s elhagy\u00e1sa",
    "Leave group": "Kil\u00e9p\u00e9s a csoportb\u00f3l",
    "Leave this page? The system may not save your changes.": "Leave this page? The system may not save your changes.",
    "Less than or equal to {maxDays_placeholder} days": "Maximum {maxDays_placeholder} nap",
    "Libraries": "K\u00f6tetek",
    "Library": "K\u00f6tet",
    "Library Type": "K\u00f6tet t\u00edpusa",
    "Library does not exist": "A k\u00f6tet nem l\u00e9tezik",
    "Limits": "Hat\u00e1rok",
    "Link": "Link",
    "Link has been copied to clipboard": "Link has been copied to clipboard",
    "Linked Devices": "Kapcsolt eszk\u00f6z\u00f6k",
    "Links": "Linkek",
    "List view": "List view",
    "List your account in global address book, so that others can find you by typing your name.": "Felhaszn\u00e1l\u00f3i fi\u00f3kja list\u00e1z\u00e1sa a glob\u00e1lis n\u00e9vjegyz\u00e9kben, \u00edgy m\u00e1sik megtal\u00e1lhatj\u00e1k \u00d6nt a nev\u00e9nek b\u00edr\u00e1s\u00e1val.",
    "Load all": "Load all",
    "Loading": "Loading",
    "Loading...": "Bet\u00f6lt\u00e9s...",
    "Location": "Helysz\u00edn",
    "Lock": "Lez\u00e1r",
    "Log out": "Kijelentkez\u00e9s",
    "Login": "Login",
    "Login ID": "Felhaszn\u00e1l\u00f3n\u00e9v",
    "Logo updated": "Logo updated",
    "Logs": "Napl\u00f3k",
    "Long text": "Long text",
    "Manage group members": "Csoporttagok kezel\u00e9se",
    "Manage members": "Manage members",
    "Mark all as read": "Mindet olvasottnak jel\u00f6lje",
    "Mark all read": "Mindet olvasottnak jel\u00f6l",
    "Mark as resolved": "Megjel\u00f6l\u00e9s megoldottk\u00e9nt",
    "Max": "Max",
    "Max number of members": "Max number of members",
    "Member": "Tag",
    "Members": "Tagok",
    "Message": "\u00dczenet",
    "Message (optional):": "\u00dczenet (opcion\u00e1lis):",
    "Migrate User": "Migrate User",
    "Mobile": "Mobil",
    "Modification Details": "M\u00f3dos\u00edt\u00e1s r\u00e9szletei",
    "Modified": "M\u00f3dos\u00edtva",
    "Modified by": "Modified by",
    "Modified by:": "Modified by:",
    "Modified files": "M\u00f3dos\u00edtott f\u00e1jlok",
    "Modifier": "M\u00f3dos\u00edt\u00f3:",
    "Modify": "Modify",
    "Modify includes modify file, move/rename file and folder": "Modify includes modify file, move/rename file and folder",
    "Modify name": "Modify name",
    "Month": "Month",
    "Month:": "H\u00f3nap:",
    "Monthly User Traffic": "Havi felhaszn\u00e1l\u00f3i forgalom",
    "More": "Tov\u00e1bb",
    "More operations": "Tov\u00e1bbi m\u0171veletek",
    "Move": "\u00c1thelyez\u00e9s",
    "Move selected item(s) to:": "Kiv\u00e1lasztott elem(ek) mozgat\u00e1sa ide: ",
    "Move {num} items": "Move {num} items",
    "Move {placeholder} to": "Move {placeholder} to",
    "Moved file": "\u00c1thelyezett f\u00e1jl",
    "Moved folder": "\u00c1thelyezett mappa",
    "Multiple select": "Multiple select",
    "My Libraries": "K\u00f6teteim",
    "My Wikis": "My Wikis",
    "Name": "N\u00e9v",
    "Name already exists": "Name already exists",
    "Name cannot be double dots": "Name cannot be double dots",
    "Name cannot be empty": "Name cannot be empty",
    "Name cannot contain backslash": "Name cannot contain backslash",
    "Name cannot contain backtick": "Name cannot contain backtick",
    "Name cannot contain curly braces": "Name cannot contain curly braces",
    "Name cannot contain dots": "Name cannot contain dots",
    "Name cannot contain slash": "Name cannot contain slash",
    "Name is required": "N\u00e9v sz\u00fcks\u00e9ges",
    "Name is required.": "N\u00e9v k\u00f6telez\u0151.",
    "Name or ID": "Name or ID",
    "Name should be string": "Name should be string",
    "Name should not include '/'.": "N\u00e9v nem tartalmazhat \"/\" jelet.",
    "Name updated": "Name updated",
    "Name(optional)": "N\u00e9v (opcion\u00e1lis)",
    "Network error": "H\u00e1l\u00f3zati hiba",
    "New": "\u00daj",
    "New Department": "\u00daj oszt\u00e1ly",
    "New Department Library": "\u00daj oszt\u00e1lyk\u00f6tet",
    "New Excel File": "\u00daj Excel f\u00e1jl",
    "New File": "\u00daj f\u00e1jl",
    "New Folder": "\u00daj k\u00f6nyvt\u00e1r",
    "New Group": "\u00daj csoport",
    "New Library": "\u00daj k\u00f6tet",
    "New Markdown File": "\u00daj Markdown f\u00e1jl",
    "New Password": "\u00daj jelsz\u00f3",
    "New Password Again": "\u00daj jelsz\u00f3 ism\u00e9t",
    "New PowerPoint File": "\u00daj PowerPoint f\u00e1jl",
    "New SeaDoc File": "New SeaDoc File",
    "New Sub-department": "\u00daj aloszt\u00e1ly",
    "New Word File": "\u00daj Word f\u00e1jl",
    "New directories": "\u00daj k\u00f6nyvt\u00e1rak",
    "New file name": "\u00daj f\u00e1jl neve",
    "New files": "\u00daj f\u00e1jlok",
    "New folder name": "New folder name",
    "New page": "\u00daj oldal",
    "New password": "\u00daj jelsz\u00f3",
    "New password cannot be the same as old password": "New password cannot be the same as old password",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.",
    "New password is too short": "Az \u00faj jelsz\u00f3 r\u00f6vid",
    "New passwords don't match": "Az \u00faj jelszavak nem egyeznek",
    "New view": "New view",
    "Next": "K\u00f6vetkez\u0151",
    "Next (Right arrow key)": "K\u00f6vetkez\u0151 (Jobbra ny\u00edl)",
    "Next modification": "K\u00f6vetkez\u0151 m\u00f3dos\u00edt\u00e1s",
    "No Admin login logs": "No Admin login logs",
    "No Admin operation logs": "No Admin operation logs",
    "No Wikis": "No Wikis",
    "No changes": "Nincs v\u00e1ltoz\u00e1s",
    "No collaborators": "No collaborators",
    "No collaborators available": "No collaborators available",
    "No comment yet.": "Nincs m\u00e9g megjegyz\u00e9s",
    "No connected devices": "Nincsenek csatlakozott eszk\u00f6z\u00f6k",
    "No deleted libraries": "No deleted libraries",
    "No favorites": "No favorites",
    "No file": "No file",
    "No file access logs": "No file access logs",
    "No file update logs": "No file update logs",
    "No filters": "Nincs sz\u0171r\u0151",
    "No folders shared": "No folders shared",
    "No groupings applied to this view.": "No groupings applied to this view.",
    "No groups": "Nincs csoport",
    "No guest invitations": "No guest invitations",
    "No invitations": "No invitations",
    "No libraries": "Nincs k\u00f6tet",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.",
    "No libraries have been shared with you": "Nincsen egyetlen k\u00f6nyvt\u00e1r sem megosztva \u00d6nnel",
    "No libraries have been shared with you from other servers.": "No libraries have been shared with you from other servers.",
    "No libraries shared": "No libraries shared",
    "No libraries shared with this group": "No libraries shared with this group",
    "No linked devices": "No linked devices",
    "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "No linked devices. You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "No login logs": "No login logs",
    "No members": "Nincs tag",
    "No more activities": "No more activities",
    "No notifications": "No notifications",
    "No option": "No option",
    "No options": "No options",
    "No options available": "No options available",
    "No permission logs": "No permission logs",
    "No properties available to be hidden": "No properties available to be hidden",
    "No public libraries": "Nincs nyilv\u00e1nos k\u00f6nyvt\u00e1r",
    "No record": "No record",
    "No result": "Nincs tal\u00e1lat",
    "No results": "Nincs tal\u00e1lat",
    "No results matching": "No results matching",
    "No share links": "No share links",
    "No sorts": "Nincs rendez\u00e9s",
    "No sync errors": "Nincs szinkroniz\u00e1l\u00e1si hiba",
    "No tags": "Nincsenek c\u00edmk\u00e9k",
    "No terms and conditions": "No terms and conditions",
    "No upload links": "No upload links",
    "No version history": "No version history",
    "None": "Nincs",
    "Not allow user to clean library trash": "Not allow user to clean library trash",
    "Not allow user to create encrypted libraries": "Not allow user to create encrypted libraries",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Megjegyz\u00e9s: a webes fel\u00fcleten megadott be\u00e1ll\u00edt\u00e1sok az adatb\u00e1zisban r\u00f6gz\u00fclnek (seahub-db/constance_config). Ezeknek magasabb a priorit\u00e1suk a config f\u00e1jlban r\u00f6gz\u00edtettekn\u00e9l.",
    "Notification": "\u00c9rtes\u00edt\u00e9s",
    "Notification Detail": "\u00c9rtes\u00edt\u00e9s r\u00e9szletei",
    "Notifications": "\u00c9rtes\u00edt\u00e9sek",
    "Notifications of file changes": "Notifications of file changes",
    "Number": "Number",
    "Number of days ago": "Number of days ago",
    "Number of days from now": "Number of days from now",
    "Number of days that keep user sign in.": "Napok sz\u00e1ma, am\u00edg a felhaszn\u00e1l\u00f3 bejelentkezve marad.",
    "Number of groups": "Csoportok sz\u00e1ma",
    "Number of links": "Number of links",
    "Number of members": "Tagok sz\u00e1ma",
    "Off": "Ki",
    "Old Password": "R\u00e9gi jelsz\u00f3",
    "Old Wikis": "Old Wikis",
    "On": "Be",
    "One month ago": "One month ago",
    "One month from now": "One month from now",
    "One week ago": "One week ago",
    "One week from now": "One week from now",
    "Online Preview": "Online el\u0151n\u00e9zet",
    "Online Read-Only": "Online Read-Only",
    "Online Read-Only folder": "Online Read-Only folder",
    "Online Read-Only library": "Online Read-Only library",
    "Online Read-Write": "Online Read-Write",
    "Online Read-Write folder": "Online Read-Write folder",
    "Online Read-Write library": "Online Read-Write library",
    "Online view is not applicable to this file format": "Az online el\u0151n\u00e9zet nem lehets\u00e9ges enn\u00e9l a f\u00e1jlform\u00e1tumn\u00e1l",
    "Only Show": "Csak megjelen\u00edt\u00e9s",
    "Only files": "Only files",
    "Only folders": "Only folders",
    "Only keep a period of history:": "Csak egy id\u0151szak megtart\u00e1sa:",
    "Only pictures": "Only pictures",
    "Only videos": "Only videos",
    "Open file": "Open file",
    "Open file in new tab": "Open file in new tab",
    "Open folder": "Open folder",
    "Open folder in new tab": "Open folder in new tab",
    "Open in new tab": "Open in new tab",
    "Open parent folder": "Sz\u00fcl\u0151k\u00f6nyvt\u00e1r megnyit\u00e1sa",
    "Open via Client": "Megnyit\u00e1s kliensben",
    "Operation": "M\u0171velet",
    "Operation succeeded.": "A m\u0171velet befejez\u0151d\u00f6tt.",
    "Operations": "M\u0171veletek",
    "Optional": "Opcion\u00e1los",
    "Options imported": "Options imported",
    "Or": "Vagy",
    "Organization": "Szervezet",
    "Organization Admin": "Szervezeti adminisztr\u00e1tor",
    "Organizations": "Szervezetek",
    "Original path": "Original path",
    "Other": "Other",
    "Other Libraries": "M\u00e1s k\u00f6tetek",
    "Others": "Others",
    "Out of quota.": "Kv\u00f3ta t\u00fall\u00e9p\u00e9s.",
    "Outdated": "Outdated",
    "Outline": "Kont\u00far",
    "Owned Libraries": "Birtokolt k\u00f6tetek",
    "Owner": "Tulajdonos",
    "Owner can use admin panel in an organization, must be a new account.": "A tulajdonos a szervezet be\u00e1ll\u00edt\u00e1sait kezelheti, \u00faj fi\u00f3knak kell lennie.",
    "Packaging...": "Csomagol\u00e1s",
    "Page name": "Page name",
    "Pages": "Oldalak",
    "Parent folder": "Parent folder",
    "Password": "Jelsz\u00f3",
    "Password again": "Jelsz\u00f3 ism\u00e9t",
    "Password cannot be blank": "A jelsz\u00f3 megad\u00e1sa k\u00f6telez\u0151",
    "Password is too short": "A jelsz\u00f3 t\u00fal r\u00f6vid",
    "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols": "Password must be at least 8 characters long and contain different characters: uppercase letters, lowercase letters, numbers, and special symbols",
    "Password removed": "Password removed",
    "Password reset": "Password reset",
    "Password set": "Password set",
    "Password strength": "Password strength",
    "Password updated": "Password updated",
    "Passwords do not match.": "Passwords do not match.",
    "Passwords don't match": "Nem egyeznek a megadott jelszavak.",
    "Path": "El\u00e9r\u00e9si \u00fat",
    "Per 4 hours": "Per 4 hours",
    "Per day": "Per day",
    "Per hour": "Per hour",
    "Per week": "Per week",
    "Permission": "Jogosults\u00e1g",
    "Permission denied": "Jogosults\u00e1g megtagadva",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "Permission denied. Please try {placeholder-left}login again.{placeholder-right}",
    "Permission name": "Permission name",
    "Person image": "Person image",
    "Picture": "Picture",
    "Pictures and videos": "Pictures and videos",
    "Platform": "Platform",
    "Please check the network.": "Ellen\u0151rizze a h\u00e1l\u00f3zatot.",
    "Please choose a .xlsx file.": "V\u00e1lasszon egy .xlsx f\u00e1jlt",
    "Please choose an image file.": "Please choose an image file.",
    "Please enter 1 or more character": "K\u00e9rem adjon meg m\u00e9g 1 vagy t\u00f6bb karaktert",
    "Please enter a new password": "K\u00e9rem adja meg az \u00faj jelsz\u00f3t",
    "Please enter a non-negative integer": "Nem negat\u00edv eg\u00e9sz sz\u00e1mot adjon meg",
    "Please enter a password.": "Please enter a password.",
    "Please enter a positive integer": "Please enter a positive integer",
    "Please enter an integer bigger than 1 as number of links.": "Please enter an integer bigger than 1 as number of links.",
    "Please enter an integer not bigger than {max_number} as number of links.": "Please enter an integer not bigger than {max_number} as number of links.",
    "Please enter days": "Adja meg a napok sz\u00e1m\u00e1t",
    "Please enter password": "K\u00e9rem adja meg a jelsz\u00f3t",
    "Please enter the new password again": "K\u00e9rem adja meg \u00fajra az \u00faj jelsz\u00f3t",
    "Please enter the old password": "K\u00e9rem adja meg a r\u00e9gi jelsz\u00f3t",
    "Please enter the password again": "K\u00e9rem adja meg a jelsz\u00f3t \u00fajra",
    "Please input at least an email.": "Adjon meg legal\u00e1bb egy e-mail c\u00edmet",
    "Please select a file": "Please select a file",
    "Please select a library to share.": "V\u00e1lasszon k\u00f6tetet a megoszt\u00e1shoz",
    "Please select an expiration time": "Please select an expiration time",
    "Please upload no more than {maxFiles} files at a time.": "Please upload no more than {maxFiles} files at a time.",
    "Preset hide properties": "Preset hide properties",
    "Preview and download": "El\u0151n\u00e9zet \u00e9s let\u00f6lt\u00e9s",
    "Preview online": "Preview online",
    "Preview only": "Csak el\u0151n\u00e9zet",
    "Previous": "El\u0151z\u0151",
    "Previous (Left arrow key)": "El\u0151z\u0151 (Balra ny\u00edl)",
    "Print": "Nyomtat\u00e1s",
    "Professional Edition": "Professzion\u00e1lis verzi\u00f3",
    "Profile": "Profil",
    "Profile Setting": "Profilbe\u00e1ll\u00edt\u00e1sok",
    "Properties": "Properties",
    "Property name": "Property name",
    "Publish": "Publik\u00e1l\u00e1s",
    "Publish Wiki": "Publish Wiki",
    "Published": "Publik\u00e1lva",
    "Quota": "Kv\u00f3ta",
    "Quota is invalid.": "\u00c9rv\u00e9nytelen kv\u00f3ta",
    "Rate": "Rate",
    "Read-Only": "Csak olvahat\u00f3",
    "Read-Only folder": "Csak olvashat\u00f3 mappa",
    "Read-Only library": "Csak olvashat\u00f3 k\u00f6tet",
    "Read-Write": "\u00cdr\u00e1s-olvas\u00e1s",
    "Read-Write folder": "\u00cdrhat\u00f3-olvashat\u00f3 mappa",
    "Read-Write library": "\u00cdrhat\u00f3-olvashat\u00f3 k\u00f6tet",
    "Really want to delete this group?": "Really want to delete this group?",
    "Really want to delete your account?": "Biztosan t\u00f6rli a fi\u00f3kot?",
    "Really want to leave this group?": "Really want to leave this group?",
    "Recognizing portraits. Please refresh the page later.": "Recognizing portraits. Please refresh the page later.",
    "Refresh": "Friss\u00edt\u00e9s",
    "Remove": "Elt\u00e1vol\u00edt\u00e1s",
    "Rename": "\u00c1tnevez\u00e9s",
    "Rename Department": "Rename Department",
    "Rename File": "F\u00e1jl \u00e1tnevez\u00e9se",
    "Rename Folder": "K\u00f6nyvt\u00e1r \u00e1tnevez\u00e9se",
    "Rename Group": "Rename Group",
    "Rename Wiki": "Rename Wiki",
    "Rename file": "Rename file",
    "Rename folder": "Rename folder",
    "Rename group to": "Csoport \u00e1tnevez\u00e9se a k\u00f6vetkez\u0151re:",
    "Rename property": "Rename property",
    "Renamed file": "\u00c1tnevezett f\u00e1jl",
    "Renamed folder": "\u00c1tnevezett mappa",
    "Renamed library": "\u00c1tnevezett k\u00f6tet",
    "Renamed or Moved files": "\u00c1tnevezett/\u00e1thelyezett f\u00e1jlok",
    "Renaming {name} failed": "Renaming {name} failed",
    "Replace": "Csere",
    "Replace file {filename}?": "Fel\u00fcl\u00edrja: {filename}?",
    "Replacing it will overwrite its content.": "A cser\u00e9je a tartalom fel\u00fcl\u00edr\u00e1s\u00e1val j\u00e1r.",
    "Report Abuse": "Report Abuse",
    "Reporter": "Reporter",
    "Reports": "Jelent\u00e9sek",
    "Required at least three letters.": "Required at least three letters.",
    "Reset": "Reset",
    "Reset Password": "Jelsz\u00f3 \u00e1t\u00e1ll\u00edt\u00e1sa",
    "Reset WebDAV Password": "Reset WebDAV Password",
    "Reset library password": "Reset library password",
    "ResetPwd": "\u00daj jelsz\u00f3",
    "Resetting user's password, please wait for a moment.": "Resetting user's password, please wait for a moment.",
    "Resolved comments": "Megoldott megjegyz\u00e9sek",
    "Restore": "Vissza\u00e1ll\u00edt\u00e1s",
    "Restore Library": "K\u00f6tet vissza\u00e1ll\u00edt\u00e1sa",
    "Restored file": "Vissza\u00e1ll\u00edtott f\u00e1jl",
    "Restored folder": "Vissza\u00e1ll\u00edtott mappa",
    "Restored library": "Vissza\u00e1ll\u00edtott k\u00f6tet",
    "Restored {name}": "Restored {name}",
    "Restored {name} and {n} other items": "Restored {name} and {n} other items",
    "Resubmit": "\u00dajrak\u00fcld\u00e9s",
    "Result": "Tal\u00e1lat",
    "Revoke Access": "Revoke Access",
    "Revoke Admin": "Admin jog elv\u00e9tele",
    "Role": "Szerep",
    "SAML config": "SAML config",
    "SAML config updated": "SAML config updated",
    "Save": "Ment\u00e9s",
    "Save Selected Items": "Save Selected Items",
    "Save as ...": "Ment\u00e9s m\u00e1sk\u00e9nt...",
    "Save to:": "Ment\u00e9s ide:",
    "Saving...": "Ment\u00e9s...",
    "Scan the QR code to view the shared content directly": "Scan the QR code to view the shared content directly",
    "SeaTable integration": "SeaTable integration",
    "Seafile": "Seafile",
    "Search": "Keres",
    "Search Groups": "Search Groups",
    "Search Libraries": "Search Libraries",
    "Search Organizations": "Search Organizations",
    "Search Users": "Search Users",
    "Search collaborator": "K\u00f6zrem\u0171k\u00f6d\u0151 keres\u00e9se",
    "Search collaborators": "Search collaborators",
    "Search department": "Szervezet keres\u00e9se",
    "Search files": "Search files",
    "Search files in this library": "F\u00e1jlok keres\u00e9se ebben a k\u00f6tetben",
    "Search groups": "Csoportok keres\u00e9se",
    "Search groups by name": "Search groups by name",
    "Search libraries by name or ID": "Search libraries by name or ID",
    "Search libraries by owner": "Search libraries by owner",
    "Search option": "Opci\u00f3 keres\u00e9se",
    "Search organizations": "Search organizations",
    "Search property": "Search property",
    "Search users": "Search users",
    "Search users...": "Felhaszn\u00e1l\u00f3k keres\u00e9se...",
    "Searching...": "Keres\u00e9s...",
    "Select": "Kiv\u00e1laszt",
    "Select File": "F\u00e1jl kiv\u00e1laszt\u00e1sa",
    "Select a department": "Select a department",
    "Select a user": "Select a user",
    "Select a user as admin": "Select a user as admin",
    "Select all": "Select all",
    "Select an option": "Egy opci\u00f3 kiv\u00e1laszt\u00e1sa",
    "Select collaborators": "Select collaborators",
    "Select libraries to share": "V\u00e1lasszon k\u00f6teteket a megoszt\u00e1shoz",
    "Select option(s)": "Opci\u00f3(k) kiv\u00e1laszt\u00e1sa",
    "Select up to 50 files": "Select up to 50 files",
    "Send": "K\u00fcld\u00e9s",
    "Send activation Email after user registration.": "Aktiv\u00e1l\u00f3 E-mail k\u00fcld\u00e9se regisztr\u00e1ci\u00f3 ut\u00e1n.",
    "Send to:": "C\u00edmzett:",
    "Sending new password...": "Sending new password...",
    "Sending...": "K\u00fcld\u00e9s...",
    "Server Version: ": "Kiszolg\u00e1l\u00f3verzi\u00f3: ",
    "Set Admin": "Admin jog megad\u00e1sa",
    "Set Contact Email": "Set Contact Email",
    "Set Download Rate Limit": "Set Download Rate Limit",
    "Set Login ID": "Set Login ID",
    "Set Name": "Set Name",
    "Set Password": "Jelsz\u00f3 be\u00e1ll\u00edt\u00e1sa",
    "Set Quota": "Kv\u00f3ta be\u00e1ll\u00edt\u00e1sa",
    "Set Upload Rate Limit": "Set Upload Rate Limit",
    "Set WebDAV Password": "Set WebDAV Password",
    "Set max number of members": "Set max number of members",
    "Set password": "Set password",
    "Set permission": "Jogosults\u00e1g be\u00e1ll\u00edt\u00e1sa",
    "Set permission of {placeholder}": "Set permission of {placeholder}",
    "Set quota": "Kv\u00f3ta be\u00e1ll\u00edt\u00e1sa",
    "Set to current": "Be\u00e1ll\u00edt\u00e1s aktu\u00e1lisnak",
    "Set user contact email": "Kapcsolat E-mail be\u00e1ll\u00edt\u00e1sa",
    "Set user default quota": "Set user default quota",
    "Set user name": "Felhaszn\u00e1l\u00f3n\u00e9v be\u00e1ll\u00edt\u00e1sa",
    "Set user quota": "Set user quota",
    "Setting library history is disabled by Admin.": "Setting library history is disabled by Admin.",
    "Settings": "Be\u00e1ll\u00edt\u00e1sok",
    "Share": "Megoszt\u00e1s",
    "Share Admin": "Megoszt\u00e1sok kezel\u00e9se",
    "Share From": "Megoszt\u00e1s innen",
    "Share Link": "Megoszt\u00e1s link",
    "Share Link Traffic": "Megoszt\u00e1si link forgalom",
    "Share Links": "Megoszt\u00e1si linkek",
    "Share To": "C\u00edmzett",
    "Share To:": "Share To:",
    "Share existing libraries": "Megl\u00e9v\u0151 k\u00f6tetek megoszt\u00e1sa",
    "Share link download": "Megoszt\u00e1si link let\u00f6lt\u00e9s",
    "Share link is copied to the clipboard.": "Megoszt\u00e1si link v\u00e1g\u00f3lapra m\u00e1solva.",
    "Share link upload": "Megoszt\u00e1si link felt\u00f6lt\u00e9s",
    "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.": "Share links cannot be generated because \"Invisible\", \"Online Read-Write\" or \"Online Read-Only\" is set for you on some folder(s) in the library.",
    "Share to group": "Megoszt\u00e1s csoporttal",
    "Share to other server": "Share to other server",
    "Share to user": "Megoszt\u00e1s felhaszn\u00e1l\u00f3val",
    "Shared By": "Megoszt\u00f3:",
    "Shared Libraries": "Megosztott k\u00f6tetek",
    "Shared Links": "Megoszt\u00e1s linkek",
    "Shared by:": "Megoszt\u00f3:",
    "Shared by: ": "Megoszt\u00f3: ",
    "Shared with all": "Mindenkivel megosztva",
    "Shared with me": "Velem megosztva",
    "Show": "Mutat",
    "Show Codes": "K\u00f3dok mutat\u00e1sa",
    "Show all": "Mindet megjelen\u00edt",
    "Show changes": "Show changes",
    "Side Nav Menu": "Oldals\u00e1vi men\u00fc",
    "Single select": "Single select",
    "Site name used in email sending": "E-mailben megjelen\u0151 oldal neve",
    "Site title shown in a browser tab": "Oldal c\u00edme a b\u00f6ng\u00e9sz\u0151 f\u00fcl\u00f6n",
    "Size": "M\u00e9ret",
    "Sort": "Rendez\u00e9s",
    "Sort ascending": "Sort ascending",
    "Sort descending": "Sort descending",
    "Space Used": "Felhaszn\u00e1lt ter\u00fclet",
    "Space Used / Quota": "T\u00e1r haszn\u00e1lva / Kv\u00f3ta",
    "Specific people with email address": "Specific people with email address",
    "Specific users in the team": "Specific users in the team",
    "Star": "Csillagoz\u00e1s",
    "Start date": "Start date",
    "Statistic": "Statisztik\u00e1k",
    "Status": "\u00c1llapot",
    "Status: enabled": "Status: enabled",
    "Storage": "T\u00e1rhely",
    "Storage Backend": "Storage Backend",
    "Storage Used": "Felhaszn\u00e1lt t\u00e1rhely",
    "Style": "St\u00edlus",
    "Submit": "Bek\u00fcld\u00e9s",
    "Success": "Sikeres",
    "Successfully added label(s) for library {placeholder}": "C\u00edmk\u00e9k hozz\u00e1adva a(z) {placeholder} k\u00f6tethez.",
    "Successfully change the group": "Successfully change the group",
    "Successfully changed library password.": "K\u00f6tetjelsz\u00f3 megv\u00e1ltoztat\u00e1sa sikeres",
    "Successfully cleared trash.": "Successfully cleared trash.",
    "Successfully converted the file.": "Successfully converted the file.",
    "Successfully copied %(name)s and %(amount)s other items.": "%(name)s m\u00e1sol\u00e1sa \u00e9s m\u00e9g %(amount)s m\u00e1sik elem\u00e9 sikeres.",
    "Successfully copied %(name)s and 1 other item.": "%(name)s m\u00e1sol\u00e1sa \u00e9s m\u00e9g 1 m\u00e1sik elem\u00e9 sikeres.",
    "Successfully copied %(name)s.": "%(name)s m\u00e1sol\u00e1sa sikeres.",
    "Successfully copied files to another library.": "Successfully copied files to another library.",
    "Successfully deleted 1 item": "1 elem sikeresen t\u00f6r\u00f6lve.",
    "Successfully deleted 1 item.": "1 elem sikeresen t\u00f6r\u00f6lve.",
    "Successfully deleted 1 share link": "Successfully deleted 1 share link",
    "Successfully deleted 1 user.": "Successfully deleted 1 user.",
    "Successfully deleted {name}": "Sikeresen t\u00f6r\u00f6lve {name}",
    "Successfully deleted {name} and {n} other items": "Successfully deleted {name} and {n} other items",
    "Successfully deleted {name} and {n} other items.": "Successfully deleted {name} and {n} other items.",
    "Successfully deleted {name}.": "Successfully deleted {name}.",
    "Successfully deleted {number_placeholder} share links": "Successfully deleted {number_placeholder} share links",
    "Successfully deleted {user_number_placeholder} users.": "Successfully deleted {user_number_placeholder} users.",
    "Successfully edited labels.": "C\u00edmk\u00e9k szerkeszt\u00e9se sikeres",
    "Successfully invited %(email) and %(num) other people.": "%(email) \u00e9s tov\u00e1bbi %(num) ember megh\u00edvva.",
    "Successfully invited %(email).": "%(email) sikeresen megh\u00edvva",
    "Successfully moved %(name)s and %(amount)s other items.": "%(name)s \u00e1thelyez\u00e9se \u00e9s m\u00e9g %(amount)s m\u00e1sik elem\u00e9 sikeres.",
    "Successfully moved %(name)s and 1 other item.": "%(name)s \u00e1thelyez\u00e9se \u00e9s m\u00e9g 1 m\u00e1sik elem\u00e9 sikeres.",
    "Successfully moved %(name)s.": "%(name)s sikeresen \u00e1tmozgatva.",
    "Successfully moved files to another library.": "Successfully moved files to another library.",
    "Successfully moved {name}.": "Successfully moved {name}.",
    "Successfully restored the library {library_name}.": "Successfully restored the library {library_name}.",
    "Successfully restored the library.": "K\u00f6nyvt\u00e1r sikeresen vissza\u00e1ll\u00edtva.",
    "Successfully restored.": "Successfully restored.",
    "Successfully revoke the admin permission of %s": "%s felhaszn\u00e1l\u00f3t\u00f3l az adminisztr\u00e1tori jogok megvon\u00e1sa sikeres",
    "Successfully revoked access of user {placeholder}.": "Successfully revoked access of user {placeholder}.",
    "Successfully revoked the admin permission of {placeholder}.": "Successfully revoked the admin permission of {placeholder}.",
    "Successfully saved": "Sikeresen elmentve",
    "Successfully sent to {placeholder}": "Sikeresen elk\u00fcldve ide: {placeholder}",
    "Successfully set %s as admin.": "%s adminisztr\u00e1tornak val\u00f3 be\u00e1ll\u00edt\u00e1sa sikeres.",
    "Successfully set it.": "Successfully set it.",
    "Successfully set library history.": "K\u00f6tetnapl\u00f3 be\u00e1ll\u00edt\u00e1sa sikeres",
    "Successfully starred {library_name_placeholder}.": "Successfully starred {library_name_placeholder}.",
    "Successfully transferred the group.": "Csoport sikeresen \u00e1tadva.",
    "Successfully transferred the library.": "K\u00f6tet \u00e1tad\u00e1sa sikeres.",
    "Successfully unlinked the device.": "Successfully unlinked the device.",
    "Successfully unshared library {placeholder}": "{placeholder} megoszt\u00e1sa sikeresen megsz\u00fcntetve",
    "Successfully unshared {name}": "Successfully unshared {name}",
    "Successfully unstarred {library_name_placeholder}.": "Successfully unstarred {library_name_placeholder}.",
    "Suggestion": "Javaslatok",
    "Switch sort mode": "Switch sort mode",
    "Switch to plain text editor": "V\u00e1lt\u00e1s sz\u00f6veges szerkeszt\u0151re",
    "Switch to rich text editor": "V\u00e1lt\u00e1s form\u00e1zott szerkeszt\u0151re",
    "Switch view mode": "Switch view mode",
    "Sync": "Szinkroniz\u00e1l\u00e1s",
    "Sync Download": "Szinkroniz\u00e1ci\u00f3 let\u00f6l\u00e9s",
    "Sync Traffic": "Szinkroniz\u00e1ci\u00f3 forgalom",
    "Sync Upload": "Szinkroniz\u00e1ci\u00f3 felt\u00f6lt\u00e9s",
    "System": "Rendszer",
    "System Admin": "Rendszer-adminisztr\u00e1tor",
    "System Info": "Rendszer inform\u00e1ci\u00f3",
    "System settings updated": "System settings updated",
    "Table": "T\u00e1bl\u00e1zat",
    "Tag not found": "Nincs el\u00e9rhet\u0151 opci\u00f3",
    "Tagged Files": "Tagged Files",
    "Tags": "Tagek",
    "Team name": "Team name",
    "Template": "Sablon",
    "Terms": "Felt\u00e9telek",
    "Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek",
    "Text": "Sz\u00f6veg",
    "Text is required.": "Text is required.",
    "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved": "The content of the document has exceeded the limit of 100000 characters, and only the first 100000 characters are saved",
    "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved": "The content of the document has exceeded the limit of 100000 characters, and the content cannot be saved",
    "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.": "The custom part of the URL must be between 5 and 30 characters long and may only contain letters (a-z), numbers, and hyphens.",
    "The file is too large. Allowed maximum size is 1MB.": "The file is too large. Allowed maximum size is 1MB.",
    "The imported options are invalid": "The imported options are invalid",
    "The least number of characters a share/upload link password should include.": "The least number of characters a share/upload link password should include.",
    "The least number of characters an encrypted library password should include.": "Titkos\u00edtott k\u00f6tet jelszav\u00e1nak minim\u00e1lis hossza.",
    "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols",
    "The link is copied to the clipboard.": "The link is copied to the clipboard.",
    "The list of added, deleted and modified files will be sent to your mailbox.": "The list of added, deleted and modified files will be sent to your mailbox.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "Maxim\u00e1lis sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek a CAPTCHA megjelen\u00edt\u00e9se el\u0151tt.",
    "The name \"{name}\" is already taken. Please choose a different name.": "A n\u00e9v \"{name}\" haszn\u00e1latban van. K\u00e9rem, v\u00e1lasszon egy m\u00e1sikat.",
    "The next month": "The next month",
    "The next numbers of days": "The next numbers of days",
    "The next week": "The next week",
    "The next year": "The next year",
    "The owner of this library has run out of space.": "A k\u00f6tet tulajdonos\u00e1nak elfogyott a t\u00e1rhelye.",
    "The password is too short.": "A jelsz\u00f3 t\u00fal r\u00f6vid.",
    "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.": "The password is too weak. It should include at least {passwordStrengthLevel} of the following: number, upper letter, lower letter and other symbols.",
    "The password will be kept in the server for only 1 hour.": "A jelsz\u00f3 egy \u00f3r\u00e1n \u00e1t lesz t\u00e1rolva a kiszolg\u00e1l\u00f3n.",
    "The past month": "The past month",
    "The past numbers of days": "The past numbers of days",
    "The past week": "The past week",
    "The past year": "The past year",
    "There is another option with this name": "There is another option with this name",
    "There is another property with this name": "There is another property with this name",
    "There is no information to display.": "There is no information to display.",
    "This file has (apparently) not been accessed yet": "Ehhez a f\u00e1jlhoz (nyilv\u00e1nval\u00f3an) m\u00e9g nem \u00e9rkezett hozz\u00e1f\u00e9r\u00e9si k\u00e9r\u00e9s ",
    "This file has been updated.": "Ez a f\u00e1jl friss\u00edtve lett.",
    "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).": "This folder has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This folder has no content at this time.": "This folder has no content at this time.",
    "This is a special group representing a department.": "Ez a speci\u00e1lis csoport egy oszt\u00e1lyt reprezent\u00e1l.",
    "This is required": "This is required",
    "This library has been set to read-only by admin and cannot be updated.": "This library has been set to read-only by admin and cannot be updated.",
    "This library has been shared to {user_amount} user(s) and {group_amount} group(s).": "This library has been shared to {user_amount} user(s) and {group_amount} group(s).",
    "This library is password protected": "Ez a k\u00f6tet jelsz\u00f3val van v\u00e9dve",
    "This month": "This month",
    "This operation will not be reverted. Please think twice!": "Ezt a m\u0171veletet nem lehet visszavonni. K\u00e9rem gondolja meg!",
    "This property can not be deleted": "This property can not be deleted",
    "This property does not support sorting": "This property does not support sorting",
    "This property is not editable": "This property is not editable",
    "This user has not created or joined any groups": "A felhaszn\u00e1l\u00f3 m\u00e9g nem hozott l\u00e9tre csoportot \u00e9s nem is tagja egyiknek sem",
    "This week": "This week",
    "This year": "This year",
    "Thumbnail": "Thumbnail",
    "Time": "Id\u0151",
    "Tip: -2 means no limit.": "Tipp: A -2 azt jelenti, hogy nincs korl\u00e1t.",
    "Tip: 0 means default limit": "Tipp: a 0 az alap\u00e9rtelmezett korl\u00e1tot jelenti",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tipp: Minden m\u00f3dos\u00edt\u00e1skor egy pillanatk\u00e9p k\u00e9sz\u00fcl, \u00edgy vissza\u00e1ll\u00edthat\u00f3 a k\u00f6tet el\u0151z\u0151 \u00e1llapota.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.",
    "Tip: you can search by keyword in name or ID.": "Tip: you can search by keyword in name or ID.",
    "Tip: you can search by keyword in name.": "Tipp: kulcssz\u00f3ra is lehet keresni a n\u00e9vben.",
    "Today": "Today",
    "Token": "Token",
    "Token:": "Token:",
    "Tomorrow": "Tomorrow",
    "Too many requests": "Too many requests",
    "Total Devices": "\u00d6sszes eszk\u00f6z",
    "Total Storage": "\u00d6sszes t\u00e1rhely",
    "Total Traffic": "\u00d6sszes forgalom",
    "Total Users": "\u00d6sszes felhaszn\u00e1l\u00f3",
    "Traffic": "Forgalom",
    "Transfer": "\u00c1tad",
    "Transfer Group": "Csoport \u00e1tad\u00e1sa",
    "Transfer Group {placeholder} to": "Transfer Group {placeholder} to",
    "Transfer Library": "K\u00f6tet \u00e1tad\u00e1sa",
    "Transfer Library {library_name}": "Transfer Library {library_name}",
    "Transfer group to": "Transfer group to",
    "Transfer to department": "Transfer to department",
    "Transfer to user": "Transfer to user",
    "Transferred group {group_name} from {user_from} to {user_to}": "{group_name} csoport \u00faj tulajdonosa {user_to}. R\u00e9gi tulajdonos: {user_from}",
    "Transferred library {library_name} from {user_from} to {user_to}": "{group_name} k\u00f6tet \u00faj tulajdonosa {user_to}. R\u00e9gi tulajdonos: {user_from}",
    "Trash": "Kuka",
    "Turn off": "Turn off",
    "Turn off extended properties": "Turn off extended properties",
    "Turn on extensible properties and views to experience a new way of managing files": "Turn on extensible properties and views to experience a new way of managing files",
    "Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s",
    "Two-factor authentication is not enabled for your account. Enable two-factor authentication for enhanced account security.": "A felhaszn\u00e1l\u00f3i fi\u00f3kon a k\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s nem akt\u00edv. Kapcsolja be a fokozott biztons\u00e1g\u00e9rt.",
    "Type": "T\u00edpus",
    "Type characters to start search": "Type characters to start search",
    "URL is copied to the clipboard": "URL is copied to the clipboard",
    "URL is required": "URL is required",
    "US": "US",
    "Undo": "Undo",
    "Unfreeze Document": "Unfreeze Document",
    "Unhandled": "Unhandled",
    "Unknown": "Ismeretlen",
    "Unlink": "Lev\u00e1laszt\u00e1s",
    "Unlink device": "Eszk\u00f6z sz\u00e9tkapcsol\u00e1sa",
    "Unlock": "Kinyit",
    "Unresolved comments": "Nem megoldott megjegyz\u00e9sek",
    "Unselect": "Unselect",
    "Unshare": "Megoszt\u00e1s t\u00f6rl\u00e9se",
    "Unshare Library": "K\u00f6tet megoszt\u00e1s\u00e1nak visszavon\u00e1sa",
    "Unstar": "Nem kedvenc",
    "Untitled": "Untitled",
    "Unwatch File Changes": "Unwatch File Changes",
    "Up": "N\u00f6vekv\u0151 sorrend",
    "Update": "Friss\u00edt\u00e9s",
    "Update Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek friss\u00edt\u00e9se",
    "Update password": "Update password",
    "Update succeeded.": "Update succeeded.",
    "Updated draft": "M\u00f3dos\u00edtott piszkozat",
    "Updated file": "Friss\u00edtett f\u00e1jl",
    "Upgrade to Pro Edition": "Friss\u00edt\u00e9s professzion\u00e1lis verzi\u00f3ra",
    "Upload": "Felt\u00f6lt\u00e9s",
    "Upload Files": "F\u00e1jlok felt\u00f6lt\u00e9se",
    "Upload Folder": "K\u00f6nyvt\u00e1r felt\u00f6lt\u00e9se",
    "Upload Link": "Felt\u00f6lt\u00e9si hivatkoz\u00e1s",
    "Upload Links": "Felt\u00f6lt\u00e9si linkek",
    "Upload file": "F\u00e1jl felt\u00f6lt\u00e9se",
    "Upload license": "Upload license",
    "Upload link is copied to the clipboard.": "Upload link is copied to the clipboard.",
    "Uploading...": "Uploading...",
    "Use custom CSS": "Egy\u00e9ni CSS haszn\u00e1lata",
    "Use information from your Identity Provider to configure Seafile": "Use information from your Identity Provider to configure Seafile",
    "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.": "Use the import/export function to transfer options quickly. (The export is in JSON format.) By pasting cells, copied from a text column, an Excel or a TXT file, you can also add options quickly.",
    "Use these values to configure your Identity Provider": "Use these values to configure your Identity Provider",
    "Used:": "Foglalt:",
    "User": "Felhaszn\u00e1l\u00f3",
    "User Permission": "Felhaszn\u00e1l\u00f3i jogosults\u00e1g",
    "User Shares": "User Shares",
    "User Storage": "Felhaszn\u00e1l\u00f3i t\u00e1rhely",
    "User can not see this folder.": "User can not see this folder.",
    "User can only view files online via browser. Files can't be downloaded.": "User can only view files online via browser. Files can't be downloaded.",
    "User can read, download and sync files.": "User can read, download and sync files.",
    "User can read, write, upload, download and sync files.": "User can read, write, upload, download and sync files.",
    "User can view and edit file online via browser. Files can't be downloaded.": "User can view and edit file online via browser. Files can't be downloaded.",
    "User info updated": "User info updated",
    "User migrate from {user_from} to {user_to}": "User migrate from {user_from} to {user_to}",
    "User not found": "Felhaszn\u00e1l\u00f3 nem tal\u00e1lhat\u00f3",
    "User {user_link} has added you to {group_link}": "User {user_link} has added you to {group_link}",
    "Username:": "Felhaszn\u00e1l\u00f3n\u00e9v:",
    "Users": "Felhaszn\u00e1l\u00f3k",
    "Verified": "Verified",
    "Verify": "Meger\u0151s\u00edt",
    "Verify Domain": "Verify Domain",
    "Version": "Verzi\u00f3",
    "Version Number": "Verzi\u00f3sz\u00e1m",
    "Version Number is required.": "Version Number is required.",
    "Version Number must be a number.": "Version Number must be a number.",
    "Video": "Vide\u00f3",
    "View": "Megtekint\u00e9s",
    "View Link": "View Link",
    "View Related Snapshot": "View Related Snapshot",
    "View Snapshot": "Pillanatk\u00e9p megtekint\u00e9se",
    "View profile and more": "Profil megtekint\u00e9se",
    "Views": "Views",
    "Virus": "Virus",
    "Virus File": "V\u00edrus f\u00e1jl",
    "Virus Scan": "V\u00edruskeres\u0151",
    "Visit count": "Visit count",
    "Visit old version page": "Visit old version page",
    "Visited": "Megtekintve",
    "Visits": "L\u00e1togat\u00e1sok ",
    "Watch File Changes": "Watch File Changes",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Web let\u00f6lt\u00e9s",
    "Web Traffic": "Web forgalom",
    "Web Upload": "Web felt\u00f6lt\u00e9s",
    "WebDAV Access": "WebDAV Access",
    "WebDAV password:": "WebDAV password:",
    "WebDAV username:": "WebDAV username:",
    "Wiki custom URL deleted": "Wiki custom URL deleted",
    "Wiki owner": "Wiki owner",
    "Wiki published": "Wiki published",
    "Wikis": "Wikik",
    "Workspace": "Saj\u00e1t fi\u00f3k",
    "Wrong password": "Hib\u00e1s jelsz\u00f3",
    "Year": "Year",
    "Yesterday": "Yesterday",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Vend\u00e9g felhaszn\u00e1l\u00f3t is hozz\u00e1adhat, aki nem tud k\u00f6tetet \u00e9s csoportot l\u00e9trehozni.",
    "You can create files quickly": "You can create files quickly",
    "You can enter multiple emails. An invitation link will be sent to each of them.": "You can enter multiple emails. An invitation link will be sent to each of them.",
    "You can use this field at login.": "Ezt a mez\u0151t haszn\u00e1lhatja a bejelentkez\u00e9shez.",
    "You do not have permission": "You do not have permission",
    "You don't have any favorite items yet": "You don't have any favorite items yet",
    "You don't have any share links": "You don't have any share links",
    "You don't have any upload links": "\u00d6nnek nincsenek felt\u00f6lt\u00e9si linkjei",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.",
    "You have not shared any folders": "Nem osztott meg egyetlen k\u00f6nyvt\u00e1rat sem",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".",
    "Your notifications will be sent to this email.": "Az \u00e9rtes\u00edt\u0151 erre az email c\u00edmre lesz elk\u00fcldve.",
    "ZIP": "ZIP",
    "Zoom in": "Nagy\u00edt\u00e1s",
    "Zoom out": "Kicsiny\u00edt\u00e9s",
    "all": "\u00f6sszes",
    "all members": "minden tag",
    "contains": "Tartalmazza",
    "days": "nap",
    "deleted": "t\u00f6r\u00f6lve",
    "deleted option": "deleted option",
    "details": "details",
    "does not contain": "Nincs tartalmazza",
    "email is required": "email is required",
    "freezed": "freezed",
    "has all of...": "has all of...",
    "has any of...": "has any of...",
    "has none of...": "has none of...",
    "icon": "ikon",
    "in all libraries": "in all libraries",
    "include the current user": "Be\u00e9rt\u00e9kezd\u00e9s",
    "is": "E\u03af\u03bd\u03b1\u03b9",
    "is after...": "is after...",
    "is any of...": "is any of...",
    "is before...": "is before...",
    "is current user's ID": "Jelenlegi felhaszn\u00e1l\u00f3i azonos\u00edt\u00f3",
    "is empty": "\u00dcres",
    "is exactly...": "is exactly...",
    "is none of...": "is none of...",
    "is not": "Nincs egyenl\u0151",
    "is not empty": "Nem \u00fcres",
    "is on or after...": "is on or after...",
    "is on or before...": "is on or before...",
    "is within...": "is within...",
    "items": "items",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}",
    "locked": "lez\u00e1rva",
    "locked by {name}": "locked by {name}",
    "mm": "mm",
    "name": "n\u00e9v",
    "not set": "not set",
    "only show {placeholder}": "only show {placeholder}",
    "s": "s",
    "selected": "selected",
    "show more": "t\u00f6bb mutat\u00e1sa",
    "sorts": "Rendez\u00e9sek",
    "starred": "kedvenc",
    "state": "\u00e1llapot",
    "successfully added user %s.": "%s hozz\u00e1ad\u00e1sa sikeres.",
    "successfully sent email to %s.": "successfully sent email to %s.",
    "unstarred": "nem kedvenc",
    "xxx cells copied": "xxx cells copied",
    "xxx cells selected": "xxx cells selected",
    "xxx record": "xxx record",
    "xxx records": "xxx records",
    "xxx records selected": "xxx records selected",
    "xxx rows are copied.": "xxx rows are copied.",
    "you can also press \u2192": "a \u2192 gombot is haszn\u00e1lhatja ",
    "{failed_files_num} file(s) failed to upload": "{failed_files_num} file(s) failed to upload",
    "{file} and {n} other files": "{file} \u00e9s {n} egy\u00e9b f\u00e1jl",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} days",
    "{number_placeholder} / Page": "{number_placeholder} / Oldal",
    "{placeholder} Access Log": "{placeholder} Access Log",
    "{placeholder} Folder Permission": "{placeholder} k\u00f6nyvt\u00e1r jogosults\u00e1ga",
    "{placeholder} History Setting": "{placeholder} Napl\u00f3be\u00e1ll\u00edt\u00e1sok",
    "{placeholder} Modification History": "{placeholder} Modification History",
    "{placeholder} Share Admin": "{placeholder} Share Admin",
    "{placeholder} Snapshot": "{placeholder} Snapshot",
    "{placeholder} Trash": "{placeholder} Trash",
    "{placeholder} Wiki Trash": "{placeholder} Wiki Trash",
    "{share_from} has cancelled the sharing of folder {repo_name}.": "{share_from} has cancelled the sharing of folder {repo_name}.",
    "{share_from} has cancelled the sharing of library {repo_name}.": "{share_from} has cancelled the sharing of library {repo_name}.",
    "{share_from} has changed the permission of folder {repo_link} to {permission}.": "{share_from} has changed the permission of folder {repo_link} to {permission}.",
    "{share_from} has changed the permission of library {repo_link} to {permission}.": "{share_from} has changed the permission of library {repo_link} to {permission}.",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} has shared a folder named {repo_link} to group {group_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} has shared a folder named {repo_link} to you.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} has shared a library named {repo_link} to group {group_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} has shared a library named {repo_link} to you.",
    "{uploaded_files_num}/{all_files_num} Files": "{uploaded_files_num}/{all_files_num} Files",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.",
    "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} created file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} created file {fileName} in library {libraryName}.": "{user} created file {fileName} in library {libraryName}.",
    "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} created folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} created folder {folderName} in library {libraryName}.": "{user} created folder {folderName} in library {libraryName}.",
    "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} deleted file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} deleted file {fileName} in library {libraryName}.": "{user} deleted file {fileName} in library {libraryName}.",
    "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} deleted folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} deleted folder {folderName} in library {libraryName}.": "{user} deleted folder {folderName} in library {libraryName}.",
    "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.": "{user} moved file {fileName} and {fileCount} other file(s) in library {libraryName}.",
    "{user} moved file {fileName} in library {libraryName}.": "{user} moved file {fileName} in library {libraryName}.",
    "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.": "{user} moved folder {folderName} and {folderCount} other folder(s) in library {libraryName}.",
    "{user} moved folder {folderName} in library {libraryName}.": "{user} moved folder {folderName} in library {libraryName}.",
    "{user} renamed file {oldFileName} {fileName} in library {libraryName}.": "{user} renamed file {oldFileName} {fileName} in library {libraryName}.",
    "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.": "{user} renamed folder {oldFolderName} {folderName} in library {libraryName}.",
    "{user} restored file {fileName} in library {libraryName}.": "{user} restored file {fileName} in library {libraryName}.",
    "{user} restored folder {folderName} in library {libraryName}.": "{user} restored folder {folderName} in library {libraryName}.",
    "{user} updated file {fileName} in library {libraryName}.": "{user} updated file {fileName} in library {libraryName}."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "Y. F j. H:i",
    "DATETIME_INPUT_FORMATS": [
      "%Y.%m.%d. %H:%M:%S",
      "%Y.%m.%d. %H:%M:%S.%f",
      "%Y.%m.%d. %H:%M",
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "Y. F j.",
    "DATE_INPUT_FORMATS": [
      "%Y.%m.%d.",
      "%Y-%m-%d"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "F j.",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "Y.m.d. H:i",
    "SHORT_DATE_FORMAT": "Y.m.d.",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "H:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H:%M",
      "%H:%M:%S.%f"
    ],
    "YEAR_MONTH_FORMAT": "Y. F"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

